/*
Measures the voltage from the development boards potentiometer and
writes it to the LCD.
*/
#include "lpc214x.h"
#include "lcd.h"
#include <stdio.h>

void Initialize(void);
void feed(void);

void IRQ_Routine (void)   __attribute__ ((interrupt("IRQ")));
void FIQ_Routine (void)   __attribute__ ((interrupt("FIQ")));
void SWI_Routine (void)   __attribute__ ((interrupt("SWI")));
void UNDEF_Routine (void) __attribute__ ((interrupt("UNDEF")));

int main (void) 
{
  int j;					// loop counter (stack variable)
  unsigned long ADCresult;
  char buf[40];
  float f;
  // Initialize the system
  Initialize();		
  //UART0Initialize(9600);			// Init UART0
  // Initialise ADC
  LCDInit();					// Init LCD
  LCDSendCommand(DISP_ON);			// LCD on
  AD0CR=8+(12<<8)+(1<<16)+(1<<21);
  PINSEL1&=0xcfffffff;
  PINSEL1|=0x10000000;
  while (1) {
    AD0CR|=(0x0001<<24);			// start 1st cnvrsn immediately
    while((AD0GDR&0x80000000) == 0);		// wait until conversion done
    AD0GDR &= 0xf8ffffff;			// Data in channel 3
    AD0GDR |= 0x07000000;			// Data in channel 3
    ADCresult = (AD0GDR & 0x0000ffc0)>>6;	// save the converted data
    sprintf(buf,"Voltage = %0.4f",(ADCresult*3.3/1023.0));
    LCDSendCommand(CLR_DISP);			//LCD clear
    LCDSendCommand(DD_RAM_ADDR);		//LCD set first row
    LCDSendTxt(buf); //write to LCD
    for (j = 0; j < 1000000; j++ );		// wait 1 sec
  }
}

#define PLOCK 0x400

void Initialize(void)
{
  // Setting Multiplier and Divider values
  PLLCFG=0x23;
  feed();
  // Enabling the PLL */	
  PLLCON=0x1;
  feed();
  // Wait for the PLL to lock to set frequency
  while(!(PLLSTAT & PLOCK)) ;
  // Connect the PLL as the clock source
  PLLCON=0x3;
  feed();
  // Enabling MAM and setting number of clocks used for Flash memory fetch (4 cclks in this case)
  MAMCR=0x2;
  MAMTIM=0x4;
  // Setting peripheral Clock (pclk) to System Clock (cclk)
  VPBDIV=0x1;
}

void feed(void)
{
  PLLFEED=0xAA;
  PLLFEED=0x55;
}

/*  Stubs for various interrupts (may be replaced later)  */
/*  ----------------------------------------------------  */

void IRQ_Routine (void) {
  while (1) ;	
}

void FIQ_Routine (void)  {
  while (1) ;	
}

void SWI_Routine (void)  {
  while (1) ;	
}

void UNDEF_Routine (void) {
  while (1) ;	
}










