/* Writes 'Hello World' to the LCD screen on the development board */

#include "lpc214x.h"
#include "lcd.h"

void Initialize(void);
void feed(void);

void IRQ_Routine (void)   __attribute__ ((interrupt("IRQ")));
void FIQ_Routine (void)   __attribute__ ((interrupt("FIQ")));
void SWI_Routine (void)   __attribute__ ((interrupt("SWI")));
void UNDEF_Routine (void) __attribute__ ((interrupt("UNDEF")));

int main (void)
{
  int j;				// loop counter (stack variable)
  // Initialize the system
  Initialize();		
  /**** LCD ****/
  LCDInit();				//Init LCD
  LCDSendCommand(DISP_ON);		//LCD on
  LCDSendCommand(CLR_DISP);		//LCD clear
  LCDSendCommand(DD_RAM_ADDR);		//LCD set first row
  LCDSendTxt("Hello World  ");			//write to LCD
}

/**********************************************************
                      Initialize
**********************************************************/

#define PLOCK 0x400

void Initialize(void)
{
  // Setting Multiplier and Divider values
  PLLCFG=0x23;
  feed();
  // Enabling the PLL */	
  PLLCON=0x1;
  feed();
  // Wait for the PLL to lock to set frequency
  while(!(PLLSTAT & PLOCK)) ;
  // Connect the PLL as the clock source
  PLLCON=0x3;
  feed();
  // Enabling MAM and setting number of clocks used for Flash memory fetch (4 cclks in this case)
  MAMCR=0x2;
  MAMTIM=0x4;
  // Setting peripheral Clock (pclk) to System Clock (cclk)
  VPBDIV=0x1;
}

void feed(void)
{
  PLLFEED=0xAA;
  PLLFEED=0x55;
}

/*  Stubs for various interrupts (may be replaced later)  */
/*  ----------------------------------------------------  */

void IRQ_Routine (void) {
  while (1) ;	
}

void FIQ_Routine (void)  {
  while (1) ;	
}


void SWI_Routine (void)  {
	while (1) ;	
}


void UNDEF_Routine (void) {
	while (1) ;	
}










